@@ -4,7 +4,7 @@
 # @Time     : 2023/2/4 10:20
 # @File     : __init__.py
 # @Project  : PyCharm
-__version__ = "0.1.17"
+__version__ = "0.1.18"
 __description__ = "pytest版 微信小程序测试"
 
 from .allureoperator import compose, attach_png, attach_text, request_allure
@@ -12,5 +12,5 @@ from .locator import Locator
 from .logoperator import LogOperator
 from .mini import Mini, MockWxMethod, MockRequest
 from .plugin import plugins
-from .timeoperator import TimeOperator
+from .timeoperator import timeoperator
 from .tools import *
